KeyCode

Enum KeyCode 

pub enum KeyCode {
Show 25 variants Backspace, Enter, Left, Right, Up, Down, Home, End, PageUp, PageDown, Tab, BackTab, Delete, Insert, F(u8), Char(char), Esc, CapsLock, ScrollLock, NumLock, PrintScreen, Pause, Menu, KeypadBegin, Null,
}
A key code representing a keyboard key.

Variants



Backspace

Backspace key.



Enter

Enter/Return key.



Left

Left arrow key.



Right

Right arrow key.



Up

Up arrow key.



Down

Down arrow key.



Home

Home key.



End

End key.



PageUp

Page Up key.



PageDown

Page Down key.



Tab

Tab key.



BackTab

Shift+Tab (backtab).



Delete

Delete key.



Insert

Insert key.



F(u8)

Function key (F1-F24).



Char(char)

A character key (includes space).



Esc

Escape key.



CapsLock

Caps Lock key (rarely reported).



ScrollLock

Scroll Lock key.



NumLock

Num Lock key.



PrintScreen

Print Screen key.



Pause

Pause key.



Menu

Menu key.



KeypadBegin

Keypad Begin (numpad 5 without numlock).



Null

Null (Ctrl+Space or Ctrl+@).

Implementations

Source

impl KeyCode

pub fn is_function_key(&self) -> bool

Check if this is a function key.

pub fn is_char(&self) -> bool

Check if this is a character key.

pub fn is_navigation(&self) -> bool

Check if this is a navigation key (arrows, home, end, page up/down).

pub fn char(&self) -> Option<char>

Get the character if this is a character key.